import re

with open("gc7/__init__.py", "r+") as f:
    content = f.read()
    content = re.sub(
        r'__version__\s*=\s*["\'].*?["\']', '__version__ = "1.1.0"', content
    )
    f.seek(0)
    f.write(content)
    f.truncate()



def hello():
    from setuptools_scm import get_version

    print("\nDernière version : " + get_version() + "\n" + ("-" * 71))
    from dotenv import load_dotenv
    import os

    load_dotenv()  # Charge les variables depuis .env
    # load_dotenv(override=True)
    
    gh_token = os.getenv("GH_TOKEN")
    pypi_token = os.getenv("PYPI_TOKEN")

    print(f"GH_TOKEN: {gh_token}\n\nPYPI_TOKEN: {pypi_token}\n")

    return f"Salut les gens 12!"


if __name__ == "__main__":
    print(hello())



try:
    # Essayer d'abord d'importer depuis le fichier généré par setuptools_scm
    from ._version import __version__
except ImportError:
    try:
        # Sinon, essayer d'utiliser setuptools_scm directement
        from setuptools_scm import get_version

        __version__ = get_version(root="../..", relative_to=__file__)
    except (ImportError, LookupError):
        try:
            # Sinon, essayer d'obtenir la version depuis le package installé
            from importlib.metadata import version

            __version__ = version("gc7")
        except:
            # Valeur par défaut si tout échoue
            __version__ = "0.0.0"
